@@ -112,8 +112,12 @@ class EmrCluster(object):
         return result_dict
 
     def run_spark_submit_step(
-        self, name, spark_submit_command, action_on_failure="CANCEL_AND_WAIT"
+        self,
+        name: str,
+        spark_submit_command,
+        action_on_failure: str = "CANCEL_AND_WAIT",
     ):
+
         step = dict(
             Name=name,
             ActionOnFailure=action_on_failure,
@@ -124,7 +128,9 @@ class EmrCluster(object):
         )
         return response["StepIds"][0]
 
-    def wait_for_step_completion(self, step_id, status_reporter=None):
+    def wait_for_step_completion(
+        self, step_id, status_reporter=None, emr_completion_poll_interval=10
+    ):
         status_reporter = status_reporter or self._default_status_reporter
         while True:
             step = self.get_step_info(step_id)
@@ -148,7 +154,7 @@ class EmrCluster(object):
             logger.debug(
                 "Emr step %s is %s", step, str(step["Step"]["Status"]["State"])
             )
-            time.sleep(10)
+            time.sleep(emr_completion_poll_interval)
 
     def _raise_error(self, step):
         if "FAILED" == step["Step"]["Status"]["State"]:
